==> haskell-hasql-1.5.0.5-104.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql
version:              1.5.0.5
visibility:           public
id:                   hasql-1.5.0.5-D13dwG1Hnoj5UOBosN4Mcc
key:                  hasql-1.5.0.5-D13dwG1Hnoj5UOBosN4Mcc
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  7c6a3d9dfee4766ef74df0cff4764c50
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql
hs-libraries:         HShasql-1.5.0.5-D13dwG1Hnoj5UOBosN4Mcc
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3
    bytestring-strict-builder-0.4.5.8-6UjkhURqr8B7Qakp8fPeVi
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hashtables-1.4.2-GYcOHygQjk55KaHvD4feXc mtl-2.3.1
    postgresql-binary-0.12.5-6JJm36AvsIuAY957XppB9e
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx text-2.0.2
    text-builder-0.6.7-LAkGrXYuG8fAiN6moYHMtp transformers-0.6.1.0
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.5.0.5-105-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql
version:              1.5.0.5
visibility:           public
id:                   hasql-1.5.0.5-D56QxJSATLi7EO6Br9LDFG
key:                  hasql-1.5.0.5-D56QxJSATLi7EO6Br9LDFG
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql
synopsis:             An efficient PostgreSQL driver with a flexible mapping API
description:
    Root of the \"hasql\" ecosystem.
    For details and tutorials see
    <https://github.com/nikita-volkov/hasql the readme>.

    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.

category:             Hasql, Database, PostgreSQL
abi:                  59bca5342d54e5fb7d98a82df34f32ef
exposed:              True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement

hidden-modules:
    Hasql.Private.Prelude Hasql.Private.Errors Hasql.Private.PTI
    Hasql.Private.IO Hasql.Private.Session Hasql.Private.Connection
    Hasql.Private.PreparedStatementRegistry Hasql.Private.Settings
    Hasql.Private.Commands Hasql.Private.Decoders
    Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
    Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
    Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
    Hasql.Private.Encoders Hasql.Private.Encoders.Array
    Hasql.Private.Encoders.Value Hasql.Private.Encoders.Params

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-1.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql
hs-libraries:         HShasql-1.5.0.5-D56QxJSATLi7EO6Br9LDFG
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3
    bytestring-strict-builder-0.4.5.8-32kx2P30sxJKZa24OiRhT8
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hashtables-1.4.2-JIYntfUsYaQ63ueo7zjueU mtl-2.3.1
    postgresql-binary-0.12.5-489HWp0msxY2tKoZpgbNFD
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn text-2.0.2
    text-builder-0.6.7-2GbfFq7sbMXC2rkto55lVx transformers-0.6.1.0
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html:         /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
